==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QStringEncoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringconverter.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qstringconverter_base.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringEncoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringEncoder")
    QStringEncoder *_ptr = reinterpret_cast<QStringEncoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStringEncoder()
void __qt_construct_QStringEncoder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder()")
    Q_UNUSED(__java_arguments)
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    jobject encoding0 = __java_arguments[0].l;
    QStringConverter::Encoding __qt_encoding0 = qtjambi_cast<QStringConverter::Encoding>(__jni_env, encoding0);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(QStringConverter::Encoding(__qt_encoding0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    jobject encoding0 = __java_arguments[0].l;
    QStringConverter::Encoding __qt_encoding0 = qtjambi_cast<QStringConverter::Encoding>(__jni_env, encoding0);
    jobject flags1 = __java_arguments[1].l;
    QStringConverterBase::Flags __qt_flags1 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags1);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(QStringConverter::Encoding(__qt_encoding0), QStringConverterBase::Flags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(const char*,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_3(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(const char*,QStringConverterBase::Flags)")
    QtJambiScope __qtjambi_scope;
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(__qt_name0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(const char*,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_4(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(const char*,QStringConverterBase::Flags)")
    QtJambiScope __qtjambi_scope;
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
    jobject flags1 = __java_arguments[1].l;
    QStringConverterBase::Flags __qt_flags1 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags1);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(__qt_name0, QStringConverterBase::Flags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStringEncoder
void __qt_destruct_QStringEncoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringEncoder")
    reinterpret_cast<QStringEncoder*>(ptr)->~QStringEncoder();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStringEncoder::QStringEncoder()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder_0, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringEncoder::QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2Lio_qt_core_QStringConverter_00024Encoding_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject encoding0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = encoding0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder_2, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringEncoder::QStringEncoder(const char*,QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2Ljava_lang_String_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring name0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder(const char*,QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = name0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder_4, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringEncoder::appendToBuffer(char*,QStringView)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_appendToBuffer_1native_1char_1ptr_1QStringView__JLjava_nio_ByteBuffer_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject out0,
 jstring in1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::appendToBuffer(char*,QStringView)", __qt_this)
        JBufferData __qt_out0_buffer(__jni_env, out0);
        char* __qt_out0 = __qt_out0_buffer.data<char>();
        QStringView  __qt_in1 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in1);

        if(__qt_out0_buffer.size()<__qt_this->requiredSpace(__qt_in1.size()))
            JavaException::raiseIndexOutOfBoundsException(__jni_env, "Buffer size is less than required space." QTJAMBI_STACKTRACEINFO);

        char* __qt_return_value = __qt_this->appendToBuffer(__qt_out0, __qt_in1);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringEncoder::encode(QStringView)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_encode_1native_1QStringView__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring in0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::encode(QStringView)", __qt_this)
        QStringView  __qt_in0 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in0);
        QStringEncoder::DecodedData<QStringView> __qt_return_value = __qt_this->encode(__qt_in0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, QByteArray(__qt_return_value));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringEncoder::operator()(QStringView)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_invoke_1native_1QStringView__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring in0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::operator()(QStringView)", __qt_this)
        QStringView  __qt_in0 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in0);
        QStringEncoder::DecodedData<QStringView> __qt_return_value = (*__qt_this)(__qt_in0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, QByteArray(__qt_return_value));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringEncoder::requiredSpace(qsizetype)const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_requiredSpace_1native_1qsizetype_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong inputLength0)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::requiredSpace(qsizetype)const", __qt_this)
        qsizetype __qt_return_value = __qt_this->requiredSpace(static_cast<qsizetype>(inputLength0));
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStringEncoder(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStringEncoder>("QStringEncoder", "io/qt/core/QStringEncoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStringEncoder, {
        ConstructorInfo(&__qt_construct_QStringEncoder_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringEncoder_1, "Lio/qt/core/QStringConverter$Encoding;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_2, "Lio/qt/core/QStringConverter$Encoding;Lio/qt/core/QStringConverterBase$Flags;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_3, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_4, "Ljava/lang/String;Lio/qt/core/QStringConverterBase$Flags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringEncoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QStringEncoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringconverter.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qstringconverter_base.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringEncoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringEncoder")
    QStringEncoder *_ptr = reinterpret_cast<QStringEncoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStringEncoder()
void __qt_construct_QStringEncoder(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder()")
    Q_UNUSED(__java_arguments)
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStringEncoder::QStringEncoder()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_QStringConverter_Encoding(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    jobject encoding0 = __java_arguments[0].l;
    QStringConverter::Encoding __qt_encoding0 = qtjambi_cast<QStringConverter::Encoding>(__jni_env, encoding0);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(QStringConverter::Encoding(__qt_encoding0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_QStringConverter_Encoding_QStringConverterBase_Flags(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    jobject encoding0 = __java_arguments[0].l;
    QStringConverter::Encoding __qt_encoding0 = qtjambi_cast<QStringConverter::Encoding>(__jni_env, encoding0);
    jobject flags1 = __java_arguments[1].l;
    QStringConverterBase::Flags __qt_flags1 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags1);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(QStringConverter::Encoding(__qt_encoding0), QStringConverterBase::Flags(__qt_flags1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStringEncoder::QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2Lio_qt_core_QStringConverter_00024Encoding_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject encoding0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder(QStringConverter::Encoding,QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = encoding0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder_QStringConverter_Encoding_QStringConverterBase_Flags, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringEncoder(const char*,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_const_char_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(const char*,QStringConverterBase::Flags)")
    QtJambiScope __qtjambi_scope;
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(__qt_name0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringEncoder(const char*,QStringConverterBase::Flags)
void __qt_construct_QStringEncoder_const_char_ptr_QStringConverterBase_Flags(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringEncoder(const char*,QStringConverterBase::Flags)")
    QtJambiScope __qtjambi_scope;
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
    jobject flags1 = __java_arguments[1].l;
    QStringConverterBase::Flags __qt_flags1 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags1);
    QStringEncoder *__qt_this = new(__qtjambi_ptr) QStringEncoder(__qt_name0, QStringConverterBase::Flags(__qt_flags1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStringEncoder::QStringEncoder(const char*,QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_initialize_1native__Lio_qt_core_QStringEncoder_2Ljava_lang_String_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring name0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringEncoder::QStringEncoder(const char*,QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = name0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringEncoder_const_char_ptr_QStringConverterBase_Flags, sizeof(QStringEncoder), typeid(QStringEncoder), false, &deleter_QStringEncoder, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStringEncoder
void __qt_destruct_QStringEncoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringEncoder")
    reinterpret_cast<QStringEncoder*>(ptr)->~QStringEncoder();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStringEncoder::appendToBuffer(char*,QStringView)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_appendToBuffer_1native_1char_1ptr_1QStringView__JLjava_nio_ByteBuffer_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject out0,
 jstring in1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::appendToBuffer(char*,QStringView)", __qt_this)
        JBufferData __qt_out0_buffer(__jni_env, out0);
        char* __qt_out0 = __qt_out0_buffer.data<char>();
        QStringView  __qt_in1 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in1);

        if(__qt_out0_buffer.size()<__qt_this->requiredSpace(__qt_in1.size()))
            JavaException::raiseIndexOutOfBoundsException(__jni_env, "Buffer size is less than required space." QTJAMBI_STACKTRACEINFO);

        char* __qt_return_value = __qt_this->appendToBuffer(__qt_out0, __qt_in1);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringEncoder::encode(QStringView)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_encode_1native_1QStringView__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring in0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::encode(QStringView)", __qt_this)
        QStringView  __qt_in0 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in0);
        QStringEncoder::DecodedData<QStringView> __qt_return_value = __qt_this->encode(__qt_in0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, QByteArray(__qt_return_value));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringEncoder::operator()(QStringView)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_invoke_1native_1QStringView__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring in0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::operator()(QStringView)", __qt_this)
        QStringView  __qt_in0 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, in0);
        QStringEncoder::DecodedData<QStringView> __qt_return_value = (*__qt_this)(__qt_in0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, QByteArray(__qt_return_value));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringEncoder::requiredSpace(qsizetype)const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringEncoder_requiredSpace_1native_1qsizetype_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong inputLength0)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QStringEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QStringEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringEncoder::requiredSpace(qsizetype)const", __qt_this)
        qsizetype __qt_return_value = __qt_this->requiredSpace(static_cast<qsizetype>(inputLength0));
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStringEncoder(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStringEncoder>("QStringEncoder", "io/qt/core/QStringEncoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStringEncoder, {
        ConstructorInfo(&__qt_construct_QStringEncoder, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringEncoder_QStringConverter_Encoding, "Lio/qt/core/QStringConverter$Encoding;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_QStringConverter_Encoding_QStringConverterBase_Flags, "Lio/qt/core/QStringConverter$Encoding;Lio/qt/core/QStringConverterBase$Flags;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_const_char_ptr, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QStringEncoder_const_char_ptr_QStringConverterBase_Flags, "Ljava/lang/String;Lio/qt/core/QStringConverterBase$Flags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringEncoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
